@@ -39,8 +39,8 @@ Q_OBJECT
 public:
   explicit FileCatalog(bool addDefaultFields, const QString& title = QString());
 
-  virtual Type type() const Q_DECL_OVERRIDE { return File; }
-  virtual int sameEntry(Data::EntryPtr entry1, Data::EntryPtr entry2) const Q_DECL_OVERRIDE;
+  virtual Type type() const override { return File; }
+  virtual int sameEntry(Data::EntryPtr entry1, Data::EntryPtr entry2) const override;
 
   static FieldList defaultFields();
 };
