@@ -38,6 +38,7 @@
 #include "translators/alexandriaexporter.h"
 #include "translators/onixexporter.h"
 #include "translators/gcstarexporter.h"
+#include "utils/string_utils.h"
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -48,11 +49,6 @@
 #include <QGroupBox>
 #include <QButtonGroup>
 #include <QRadioButton>
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include <QTextCodec>
-#else
-#include <QStringConverter>
-#endif
 #include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -104,13 +100,9 @@ ExportDialog::ExportDialog(Tellico::Export::Format format_, Tellico::Data::CollP
   m_encodeUTF8->setWhatsThis(i18n("Encode the exported file in Unicode (UTF-8)."));
   vlay2->addWidget(m_encodeUTF8);
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-  const auto localeName = QTextCodec::codecForLocale()->name();
-#else
-  const auto localeName = QStringConverter::nameForEncoding(QStringConverter::System);
-#endif
-  QString localStr = i18n("Encode in user locale (%1)",
-                          QLatin1String(localeName));
+  const auto localeName = Tellico::localeEncodingName();
+  const QString localStr = i18n("Encode in user locale (%1)",
+                                QLatin1String(localeName));
   m_encodeLocale = new QRadioButton(localStr, group2);
   m_encodeLocale->setWhatsThis(i18n("Encode the exported file in the local encoding."));
   vlay2->addWidget(m_encodeLocale);
