@@ -44,14 +44,14 @@ public:
   ImageFieldWidget(Data::FieldPtr field, QWidget* parent);
   virtual ~ImageFieldWidget() {}
 
-  virtual QString text() const Q_DECL_OVERRIDE;
-  virtual void setTextImpl(const QString& text) Q_DECL_OVERRIDE;
+  virtual QString text() const override;
+  virtual void setTextImpl(const QString& text) override;
 
 public Q_SLOTS:
-  virtual void clearImpl() Q_DECL_OVERRIDE;
+  virtual void clearImpl() override;
 
 protected:
-  virtual QWidget* widget() Q_DECL_OVERRIDE;
+  virtual QWidget* widget() override;
 
 private:
   ImageWidget* m_widget;
