@@ -214,3 +214,27 @@ void ItunesFetcherTest::testMultiDisc() {
   QCOMPARE(tracks2.count(), 23);
   QVERIFY(!tracks2.first().isEmpty());
 }
+
+// https://bugs.kde.org/show_bug.cgi?id=499401
+void ItunesFetcherTest::testMultiDiscOldWay() {
+  KConfigGroup cg = KSharedConfig::openConfig(QString(), KConfig::SimpleConfig)->group(QStringLiteral("itunes"));
+  cg.writeEntry("Split Tracks By Disc", false);
+
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Album, Tellico::Fetch::Keyword,
+                                       QStringLiteral("Hamilton: An American Musical"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::ItunesFetcher(this));
+  fetcher->readConfig(cg);
+
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
+
+  QVERIFY(!results.isEmpty());
+
+  Tellico::Data::EntryPtr entry = results.at(0);
+  auto trackField = entry->collection()->fieldByName(QStringLiteral("track"));
+  QVERIFY(trackField);
+  QVERIFY(!entry->collection()->hasField(QStringLiteral("track2")));
+  // verify the title was not updated to include the disc number
+  QVERIFY(trackField->title() == i18n("Tracks"));
+  QStringList tracks = Tellico::FieldFormat::splitTable(entry->field(QStringLiteral("track")));
+  QCOMPARE(tracks.count(), 46);
+}
