@@ -34,6 +34,8 @@ private Q_SLOTS:
   void initTestCase();
   void testScienceDirect();
   void testMultiple();
+  void testMetadata();
+  void testBookCollection();
 };
 
 #endif
