@@ -69,7 +69,7 @@ void UPCItemDbFetcherTest::testFightClub() {
   Tellico::Data::EntryPtr entry = results.at(0);
   QVERIFY(entry);
 
-  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Fight Club"));
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Fight Club Mill Creek Drama"));
 //  QCOMPARE(entry->field(QStringLiteral("year")), QStringLiteral("1999"));
   QCOMPARE(entry->field(QStringLiteral("barcode")), QStringLiteral("024543617907"));
   QCOMPARE(entry->field(QStringLiteral("medium")), QStringLiteral("Blu-ray"));
@@ -92,7 +92,7 @@ void UPCItemDbFetcherTest::testCatan() {
   QVERIFY(entry);
 
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Settlers of Catan Board Game"));
-  QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Mayfair Games"));
+  QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Catan Studio"));
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
   QVERIFY(!entry->field(QStringLiteral("description")).isEmpty());
@@ -110,11 +110,11 @@ void UPCItemDbFetcherTest::test1632() {
   Tellico::Data::EntryPtr entry = results.at(0);
   QVERIFY(entry);
 
-  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Ring of Fire: 1632"));
-  QEXPECT_FAIL("", "Author data is in publisher field", Continue);
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("1632"));
+//  QEXPECT_FAIL("", "Author data is in publisher field", Continue);
   QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("Eric Flint"));
   QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("9780671319724"));
-  QEXPECT_FAIL("", "Author data is in publisher field", Continue);
+//  QEXPECT_FAIL("", "Author data is in publisher field", Continue);
   QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Baen"));
   QCOMPARE(entry->field(QStringLiteral("binding")), QStringLiteral("Paperback"));
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
